@@ -31,9 +31,13 @@ class OclResourceList(object):
         """ Add two resource lists together """
         _output_resources = list(self._resources)
         for resource in new_resources:
-            _output_resources.append(resource.copy())
+            _output_resources.append(resource)
         return OclResourceList(_output_resources)
 
+    def __iadd__(self, new_resources):
+        self.append(new_resources)
+        return self
+
     def __eq__(self, other):
         """ Return whether the two objects are equal, i.e. have the same resource lists """
         if len(self) != len(other):
@@ -47,6 +51,17 @@ class OclResourceList(object):
         """ Return whether the two objects have different resource lists """
         return not self.__eq__(other)
 
+    def chunk(self, chunk_size):
+        """
+        Return the OclResourceList as a list of OclResourceList objects with maximum
+        size of chunk_size.
+        """
+        chunked_lists = [self._resources[i:i + chunk_size] for i in xrange(0, len(self._resources), chunk_size)]
+        chunked_resource_lists = []
+        for chunked_list in chunked_lists:
+            chunked_resource_lists.append(OclResourceList(chunked_list))
+        return chunked_resource_lists
+
     def next(self):
         """ Get the next item in the list """
         if self._current_iter >= len(self._resources):
@@ -65,14 +80,20 @@ class OclResourceList(object):
             self._urls.append(OclResourceList.get_resource_url(resource))
 
     def append(self, resources):
-        """ Add one resource or a list of resources to the list """
-        if not isinstance(resources, list):
+        """
+        Add one resource or a list of resources to this object
+        :param resources: <dict>, <list>, <OclResourceList>
+        """
+        if isinstance(resources, dict):
             resources = [resources]
-        for resource in resources:
-            if not isinstance(resource, dict):
-                raise TypeError("Cannot append resource of type '%s'" % type(resource))
-            self._urls.append(OclResourceList.get_resource_url(resource))
-            self._resources.append(resource)
+        if isinstance(resources, list) or isinstance(resources, OclResourceList):
+            for resource in resources:
+                if not isinstance(resource, dict):
+                    raise TypeError("Cannot append resource of type '%s'" % type(resource))
+                self._urls.append(OclResourceList.get_resource_url(resource))
+                self._resources.append(resource)
+        else:
+            raise TypeError("Cannot append resource of type '%s'" % type(resources))
 
     def __getitem__(self, index):
         """ Get an item from the list """
